@@ -8,20 +8,12 @@ import copy
 import numpy as np
 from numpy.linalg import inv
 
-ELASTICITYMODULE = False
-# try:
-#     import lauetoolsnn.lauetools.elasticity as el
-#     ELASTICITYMODULE = True
-# except:
-#     from lauetools import elasticity as el
-#     ELASTICITYMODULE = True
-
 try:
-    from lauetools.dict_LaueTools import dict_Materials, dict_Stiffness
+    from lauetools.dict_LaueTools import dict_Materials
     from lauetools.wyckpos_lauetools import testhklcond_generalrules
     from lauetools import generaltools as GT
 except:
-    from lauetoolsnn.lauetools.dict_LaueTools import dict_Materials, dict_Stiffness
+    from lauetoolsnn.lauetools.dict_LaueTools import dict_Materials
     from lauetoolsnn.lauetools.wyckpos_lauetools import testhklcond_generalrules
     import lauetoolsnn.lauetools.generaltools as GT    
     
@@ -1230,123 +1222,6 @@ def strain_from_crystal_to_sample_frame2(strain, UBmat, sampletilt=40.0):
 
 #     return deviatoric_strain_sampleframe
 
-
-def hydrostaticStrain(deviatoricStrain, key_material, UBmatrix, assumption="stresszz=0",
-                                                                        sampletilt=40.0):
-    r"""
-    Computes full strain & stress from deviatoricStrain (voigt notation in crystal frame), material
-    and mechanical assumtion
-
-    C a*b*c* = (UB-1P)**2 C sample (P-1 UB)**2
-    qxyzLT = P qsample
-    qxyzLT=UB qcrystal(a*b*c*)
-    stress xyzLT = P stress sample P-1
-
-    sigma =C eps
-    rank 2 = rank 4 rank 2
-
-    voigt notation
-    sigma = C eps
-
-    (s11,s22,s33,s23,s13,s12)=C (eps11,eps22,eps33,2*eps23,2*eps13,2*eps12)
-    with C = 6x6 'matrix'
-
-    full strain = deviatoric_strain + hydrostatic_strain/3 * Identity
-      eps =eps_dev+eps_h/3 * Idmatrix(3,3):
-     (s11,s22,s33,s23,s13,s12)=C (eps_dev11+eps_h/3,
-                                 eps_dev22+eps_h/3,
-                                eps_dev33+eps_h/3,
-                                 2*eps_dev23,
-                                 2*eps_dev13,
-                                 2*eps_dev12)
-    to get  eps_h since
-    mechanical assumption on sigmazz=0 corresponds to third component calcutation:
-    scalar product of C[2] with eps =0
-
-    """
-    if not ELASTICITYMODULE:
-        print('You need to install elasticity.py module!')
-        return
-
-    if assumption != "stresszz=0":
-        print("not yet implemented")
-        return None
-
-    symmetry = dict_Stiffness[key_material][2]
-    if symmetry != "cubic":
-        print("not yet implemented")
-        return None
-    # constant in crystal frame
-    c11, c12, c44 = dict_Stiffness[key_material][1]
-
-    print("c11, c12, c44", c11, c12, c44)
-
-    # Cmatrix = np.array( [ [c11, c12, c12, 0, 0, 0],
-    #         [c12, c11, c12, 0, 0, 0],
-    #         [c12, c12, c11, 0, 0, 0],
-    #         [0, 0, 0, c44, 0, 0],
-    #         [0, 0, 0, 0, c44, 0],
-    #         [0, 0, 0, 0, 0, c44], ], dtype=np.float, )
-
-    P = GT.matRot([0, 1, 0], -sampletilt)
-
-    transformmatrix = np.dot(np.linalg.inv(UBmatrix), P)
-    #     invtransformmatrix = np.linalg.inv(transformmatrix)
-    #     transformmatrix = np.eye(3)
-
-    C_sampleframe = el.rotate_cubic_elastic_constants(c11, c12, c44, transformmatrix)
-
-    print("C_sampleframe", C_sampleframe)
-
-    deviatoricStrain_sampleframe = strain_from_crystal_to_sample_frame2(
-        deviatoricStrain, UBmatrix)
-
-    # with UBmatrix=np.eye(3)
-    #     deviatoricStrain_crystalframe=np.array([[ 0.00082635, -0.00076604, -0.00098481],
-    #                                    [ 0.        , -0.001     ,  0.        ],
-    #                                    [-0.00098481, -0.00064279,  0.00117365]])
-
-    #     deviatoricStrain_sampleframe = np.array([[-0.001, -0.0, 0], [0.0, -0.001, 0], [0, 0, 0.002]])
-    print("deviatoricStrain_sampleframe", deviatoricStrain_sampleframe)
-
-    # use elasticity module instead
-    devstrain_voigt_sampleframe = np.zeros(6)
-    for i in list(range(6)):
-        val = deviatoricStrain_sampleframe[el.Voigt_notation[i]]
-        if i >= 3:
-            val *= 2.0
-        devstrain_voigt_sampleframe[i] = val
-
-    print("devstrain_voigt_sampleframe", devstrain_voigt_sampleframe)
-
-    print(" numerator", np.dot(devstrain_voigt_sampleframe, C_sampleframe[2]))
-    print("denominator", np.sum(C_sampleframe[2][:3]))
-    print("C_sampleframe[2]", C_sampleframe[2])
-
-    # third row gives an equation where eps_hydro can be extracted
-    # 0 = np.dot(devstrain_voigt,C_sampleframe[2])+eps_hydro/3.*np.sum(np.dot(devstrain_voigt[:3],C_sampleframe[2][3:]))
-    hydrostrain = (-np.dot(devstrain_voigt_sampleframe, C_sampleframe[2]) * 3
-        / np.sum(C_sampleframe[2][:3]))
-
-    print("hydrostatic strain", hydrostrain)
-
-    fullstrain_sampleframe = deviatoricStrain_sampleframe + hydrostrain / 3.0 * np.eye(3)
-
-    fullstrain_voigt_sampleframe = (
-        devstrain_voigt_sampleframe + hydrostrain / 3.0 * np.array([1, 1, 1, 0, 0, 0]))
-
-    fullstress_voigt_sampleframe = np.dot(C_sampleframe, fullstrain_voigt_sampleframe)
-
-    print("fullstress_voigt_sampleframe", fullstress_voigt_sampleframe)
-    print("fullstress_voigt_sampleframe[2] stress normal to sample surface (must be 0)",
-        fullstress_voigt_sampleframe[2])
-
-    return (fullstrain_sampleframe,
-        fullstress_voigt_sampleframe,
-        hydrostrain,
-        deviatoricStrain_sampleframe)
-
-
 def matstarlab_to_matstarlabOND(matstarlab=None, matLT3x3=None, verbose=0):  # OR
     r"""
     Orthonormalisation of matrix with to a*,b*,c* as columns
