@@ -39,12 +39,6 @@ except:
             DEFAULT_DETECTOR_DISTANCE, DEFAULT_DETECTOR_DIAMETER, DEFAULT_TOP_GEOMETRY)
 
 USE_CYTHON = False
-try:
-    import generatehkl
-    USE_CYTHON = True
-except ImportError:
-    #print("-- warning. Cython compiled module for fast computation of Laue spots is not installed!")
-    USE_CYTHON = False
 
 DEG = np.pi / 180.0
 
